<template>
    <div class="overflow-hidden">
        <div id="olMap" class="map" style="position:relative;">
          <div id="stateDiv">
            <div class="detailStateDiv">
              <table cellpadding="5" cellspacing="3">
                <tr>
                  <td><img src="../../assets/img/camera_device.png" class="deviceImg" />{{deviceState.caremaState.count}}<span>|</span><span><label class="abnormal">{{deviceState.caremaState.abNormal}}</label><label>{{deviceState.caremaState.normal}}</label></span></td>
                  <td><img src="../../assets/img/ip_device.png" class="deviceImg" />{{deviceState.ipState.count}}<span>|</span><span><label class="abnormal">{{deviceState.ipState.abNormal}}</label><label>{{deviceState.ipState.normal}}</label></span></td>
                  <td><img src="../../assets/img/visitor_device.png" class="deviceImg" />{{deviceState.padState.count}}<span>|</span><span><label class="abnormal">{{deviceState.padState.abNormal}}</label><label>{{deviceState.padState.normal}}</label></span></td>
                </tr>
              </table>
            </div>
            <div class="statistStateDiv">
              <el-tag type="danger">异常({{deviceState.abNormalCount}})</el-tag>
              <el-tag type="success">正常({{deviceState.normalCount}})</el-tag>
            </div>
          </div>
          <div class="areaDiv">
            <template>
              <el-menu default-active="systemManage" @open="handleOpen" @close="handleClose" background-color="#545c64" text-color="#fff" active-text-color="#ffd04b">
                <NavMenu :navMenus="menuData"></NavMenu>
              </el-menu>
            </template>
          </div>
          <div class="areaManage">
            <el-button style="background-color:#545c64;color:#fff;border:0;">管理</el-button>
          </div>
        </div>
    </div>
</template>
<script>
import Map from 'ol/Map'
import View from 'ol/View'
import TileLayer from 'ol/layer/Tile'
// import XYZ from 'ol/source/XYZ'
import TileWMS from 'ol/source/TileWMS'
import NavMenu from '@/components/navMenu/NavMenu'
import 'ol/ol.css'
import { Tag, Menu, Button } from 'element-ui'
export default {
  metaInfo: {
    title: '地图管理'
  },
  components: {
    elTag: Tag,
    elMenu: Menu,
    NavMenu: NavMenu,
    elButton: Button
  },
  data() {
    return {
      deviceState: {
        abNormalCount: 0, // 异常总数
        normalCount: 6, // 正常总数
        caremaState: {
          count: 2,
          abNormal: 0,
          normal: 2
        },
        ipState: {
          count: 2,
          abNormal: 1,
          normal: 1
        },
        padState: {
          count: 2,
          abNormal: 0,
          normal: 2
        }
      },
      zoomLevel: 0,
      centerLon: 0,
      centerLat: 0,
      baseLayers: [],
      businessLayers: {},
      projection: '',
      currentZoomLevel: 0,
      menuData: [{
        'entity': {
          'id': 1,
          'name': 'area1',
          'icon': 'el-icon-message',
          'alias': '教学楼'
        },
        'childs': [{
          'entity': {
            'id': 3,
            'name': 'area2',
            'icon': 'el-icon-loading',
            'alias': '一层'
          }}, {
          'entity': {
            'id': 4,
            'name': 'area3',
            'icon': 'el-icon-bell',
            'alias': '二层'
          }
        }, {
          'entity': {
            'id': 5,
            'name': 'area4',
            'icon': 'el-icon-bell',
            'alias': '三层'
          }
        }, {
          'entity': {
            'id': 6,
            'name': 'area5',
            'icon': 'el-icon-bell',
            'alias': '四层'
          }
        }, {
          'entity': {
            'id': 7,
            'name': 'area6',
            'icon': 'el-icon-bell',
            'alias': '五层'
          }
        }]
      }]
    }
  },
  methods: {
    mapInit() {
      let layers = []
      if (this.baseLayers.length > 0) {
        for (let urlStr of this.baseLayers) {
          layers.push(
            new TileLayer({
              visible: true,
              source: new TileWMS({
                url: urlStr,
                params: {
                  'LAYERS': 'basic:shpGroup',
                  'TILED': true
                },
                serverType: 'geoserver'
              })
            })
          )
        }
      } else {
        return
      }
      var map = new Map({
        layers: layers,
        target: 'olMap',
        view: new View({
          projection: this.projection,
          center: [this.centerLon, this.centerLat],
          zoom: this.zoomLevel
        })
      })
      console.info(map)
    },
    handleOpen(key, keyPath) {
      console.log(key, keyPath)
    },
    handleClose(key, keyPath) {
      console.log(key, keyPath)
    }
  },
  created() {
    this.zoomLevel = 11
    this.centerLon = 540000
    this.centerLat = 3222260
    this.projection = 'EPSG:900913'
    // this.baseLayers.push('http://t3.tianditu.com/DataServer?T=vec_w&x={x}&y={y}&l={z}')
    // this.baseLayers.push('http://t3.tianditu.com/DataServer?T=cva_w&x={x}&y={y}&l={z}')
    this.baseLayers.push('http://192.168.1.203:2080/geoserver/wms')
  },
  mounted() {
    this.mapInit()
  }
}
</script>
<style>
#stateDiv{
  position: absolute;
  top: 3px;
  left: 50px;
  width: 400px;
  height: 70px;
}
.detailStateDiv{
  width: 100%;
  height: 40px;
}
.statistStateDiv{
  width: 100%;
}
.abnormal{
  color: red;
  margin:0 3px 0 3px;
}
.abnormalDiv{
  width: 90px;
  float: left;
  margin: 0 5px 0 5px;
  text-align: center;
  color:white;
  background-color: red;
  padding-top: 5px;
}
.normalDiv{
  width: 90px;
  float: left;
  margin: 0 5px 0 5px;
  text-align: center;
  color: white;
  background-color: green;
  padding-top: 5px;
}
.areaDiv{
  position: absolute;
  background-color: #ddd;
  width: 130px;
  height: 250px;
  top: 20px;
  right: 20px;
  display: block;
  z-index: 9999;
  overflow: scroll;
}
.deviceImg{
  width:30px;
  height:30px;
}
.areaManage{
  position: absolute;
  width: 130px;
  top: 270px;
  right: 20px;
  display: block;
  z-index: 9999;
  text-align: center;
  background-color: #545c64;
}
</style>
